@@ -68,7 +68,7 @@ class Powerwall:
         return LoginResponse(response)
 
     def login(self, password: str, email: str = "", force_sm_off: bool = False) -> dict:
-        return self.login_as(User.CUSTOMER, email, password, force_sm_off)
+        return self.login_as(User.CUSTOMER, password, email, force_sm_off)
 
     def logout(self):
         self._api.logout()
@@ -77,7 +77,7 @@ class Powerwall:
         return self._api.is_authenticated()
 
     def run(self):
-        self._api.get_sitemater_run()
+        self._api.get_sitemaster_run()
 
     def stop(self):
         self._api.get_sitemaster_stop()
@@ -171,3 +171,6 @@ class Powerwall:
 
     def get_api(self):
         return self._api
+
+    def close(self):
+        self._api.close()
\ No newline at end of file
